#
# spec file for package rabbitmq-c
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2012-2015 Remi Collet
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global libname     librabbitmq
%global majsonum    4
Name:           rabbitmq-c
Version:        0.15.0
Release:        1.1
Summary:        Client library for AMQP
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/alanxz/rabbitmq-c
Source0:        https://github.com/alanxz/rabbitmq-c/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# [bsc#1232541], https://github.com/alanxz/rabbitmq-c/issues/846
Patch0:         rabbitmq-c-default-cacert-location.patch
BuildRequires:  cmake > 2.8.12
BuildRequires:  gcc
BuildRequires:  openssl-devel
# For tools
BuildRequires:  popt-devel
# For man page
BuildRequires:  xmlto
# SECTION test requirements
BuildRequires:  rabbitmq-server
BuildRequires:  rabbitmq-server-plugins
# /SECTION

%description
This is a C-language AMQP client library for use with AMQP servers
speaking protocol versions 0-9-1.

%package -n %{libname}%{majsonum}
Summary:        Client library for AMQP
Group:          Development/Libraries/C and C++

%description -n %{libname}%{majsonum}
This is a C-language AMQP client library for use with AMQP servers
speaking protocol versions 0-9-1.

%package -n %{libname}-devel
Summary:        Header files and development libraries for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{majsonum} = %{version}

%description -n %{libname}-devel
This package contains the header files and development libraries
for %{name}.

%package -n %{name}-tools
Summary:        Example tools built using the librabbitmq package
Group:          Development/Libraries/C and C++

%description -n %{name}-tools
This package contains example tools built using %{name}. It provides:
amqp-consume        Consume messages from a queue on an AMQP server
amqp-declare-queue  Declare a queue on an AMQP server
amqp-delete-queue   Delete a queue from an AMQP server
amqp-get            Get a message from a queue on an AMQP server
amqp-publish        Publish a message on an AMQP server

%prep
%autosetup -p1

%build
# static lib required for tests
%cmake \
  -DBUILD_TOOLS_DOCS:BOOL=ON \
  -DBUILD_STATIC_LIBS:BOOL=ON \
  -DBUILD_TOOLS:BOOL=ON
%cmake_build

%install
%cmake_install
rm %{buildroot}%{_libdir}/%{libname}.a

%check
# check .pc is usable
grep @ %{buildroot}%{_libdir}/pkgconfig/librabbitmq.pc && exit 1
# upstream tests
#
# https://github.com/alanxz/rabbitmq-c/issues/602
# rabbitmq-server needs to run only for test_basic,
# which can be skipped in case this will bring some
# issues
exit_code=0
echo "### Starting RabbitMQ server .."
pid_file="/home/abuild/rabbitmq/rabbitmq.pid"
export RABBITMQ_PID_FILE=$pid_file
export RABBITMQ_LOG_BASE=/home/abuild/rabbitmq/log
export RABBITMQ_MNESIA_BASE=/home/abuild/rabbitmq/mnesia
%if 0%{?suse_version} <= 1500
export RABBITMQ_SCHEMA_DIR=/home/abuild/rabbitmq/schema
export RABBITMQ_GENERATED_CONFIG_DIR=/home/abuild/rabbitmq/config
%endif
sbin_base=/usr/lib*/rabbitmq/lib/rabbitmq_server-*/sbin
$sbin_base/rabbitmq-server&
sleep 10
$sbin_base/rabbitmqctl await_startup
if ! $sbin_base/rabbitmqctl ping; then
  # bsc#1198202 - FTBFS: rabbitmq-c won't compile on SP4
  # handle the situation when rabbitmq server will not start
  # in time
  echo '### Server have not managed to start until now, giving up'
  epmd -kill || true
  exit 0
fi
echo "### Done, running tests"
%ctest || exit_code=1
echo "### Stopping RabbitMQ server .."
$sbin_base/rabbitmqctl stop
# needs to wait: Killing not allowed - living nodes in database.
sleep 10
# do not bother when kill won't succeed
epmd -kill || true
echo "### Done"
exit $exit_code

%post -n %{libname}%{majsonum} -p /sbin/ldconfig
%postun -n %{libname}%{majsonum} -p /sbin/ldconfig

%files -n %{libname}%{majsonum}
%license LICENSE
%{_libdir}/%{libname}.so.%{majsonum}
%{_libdir}/%{libname}.so.%{version}

%files -n %{libname}-devel
%doc AUTHORS THANKS *.md examples
%{_libdir}/%{libname}.so
%{_includedir}/amqp*
%{_includedir}/rabbitmq-c
%{_libdir}/cmake/%{name}
%{_libdir}/pkgconfig/%{libname}.pc

%files -n %{name}-tools
%{_bindir}/amqp-*
%{_mandir}/man1/amqp-*.1%{?ext_man}
%{_mandir}/man7/librabbitmq-tools.7%{?ext_man}

%changelog
* Sun Jan 19 2025 Matthias Eliasson <elimat@opensuse.org>
- version update to 0.15.0
  [#]# v0.15.0 - 2024-11-19
  [#]# Fixed
  - Warning on MacOS about incompatible function declaration
  - Logic when decoding AMQP data after bad data may cause crash (#837)
  - Use SSL_get1_peer_certificate when compiling against OpenSSL 3+
  [#]# Changed
  - Updates to various github actions.
  [#]# Added
  - Add amqp_publisher_confirm_wait function (#841)
  - Add amqp_literal_bytes macro (#844)
* Wed Nov  6 2024 pgajdos@suse.com
- tools: fix default cacert location
- added patches
  fix [bsc#1232541]
  + rabbitmq-c-default-cacert-location.patch
* Wed Apr  3 2024 pgajdos@suse.com
- version update to 0.14.0
  [#]# v0.14.0 - 2024-03-18
  [#]# Fixed
  - Fix potential stackoverflow in decoding table and array
  - Fix issue with Mach-O version (#758)
  - Make dependency on OpenSSL in rabbitmq-c.cmake match what is built (#725)
  - Fix pkg-config generation when CMAKE_INSTALL_DIR is absolute (#733)
  - Fix issue with amqp_basic_publish blocking in non-blocking mode (#780)
  - Fix SSL hostname check (#784)
  - Fix bug in amqp-consume documentation #791
  [#]# Changed
  - CMake minimum version is now 3.22
  - OpenSSL minimum version is now 1.1.1
  - Minimum TLS version supported is v1.2 (v1.3 is also supported).
  - OpenSSL ENGINE APIs are conditionally enabled based on availability
  [#]# Added
  - Add option to read username/password from file in tools (#781)
  - Add amqp_ssl_socket_enable_default_verify_paths API to allow loading from default certification paths
  - rabbitmq-c can be compiled against BoringSSL (#814)
* Fri Jun 23 2023 pgajdos@suse.com
- version update to 0.13.0
  [#]# v0.13.0 - 2023-02-05
  [#]# Fixed
  - Fixed missing option to not install static library (#665)
  - Missing pkgconfig version in v0.12.0 output (#755, #751)
  - Correct return value from amqp_ssl_socket_set_key_buffer (#723)
  [#]# Changed
  - Remove OpenSSL code no longer needed when used with OpenSSL >= 1.1.0. (Fixed: #715, #737)
  [#]# Added
  - Integration with OSS-Fuzz (#736)
  [#]# v0.12.0 - 2023-01-31
  [#]# Changed
  - rabbitmq-c now compiles as C99
  - CMake 3.12 is new minimum required version
  - CMake -DBUILD_TESTS renamed to -DBUILD_TESTING
  - CMake -DBUILD_EXAMPLES now defaults to OFF
  - CMake -DBUILD_TOOLS now defaults to OFF
  - Unix library version now matches the release version, SONAME remains the same.
  - Modernized CMake scripts to better adopt modern standards
  - Public headers have moved to rabbitmq-c/ directory
  - Dropped support for MSVC older than VS 2010
  - Dropped support for OpenSSL v1.1.0 and older
  - Minimum SSL version set to TLSv1.2
  - Updated to RabbitMQ framing to v3.8.19
- fixes CVE-2023-35789 [bsc#1212499]
* Wed Apr 27 2022 pgajdos@suse.com
- give up to run testsuite when the server will not start in time
  [bsc#1198202]
* Mon Sep  6 2021 pgajdos@suse.com
- %%check: fix testsuite run
* Fri May  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.11.0
  * Added rabbitmq-c-config.cmake
  * Add amqp_set_ssl_engine API to allow setting OpenSSL engine
  * Add amqp_ssl_socket_set_key_engine API to allow setting OpenSSL
    engine
  * Add support use of password-protected SSL keys
  * Update OpenSSL library initialization to current best practices
  * Updates to OpenSSL to support v3.0.0
  * Restore correct non-blocking behavior using OpenSSL v1.1.1
  * Fix invalid format in generated pkg-config file
  * Fix invalid AMQP_STATUS_HEARTBEAT_TIMEOUT
  * Fix incorrect port when using --server flag in CLI tools
- Drop upstream merged reproducible.patch
* Tue Dec 22 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Thu Dec 17 2020 pgajdos@suse.com
- %%check: use rabbitmqctl await_startup to wait for RabbitMQ
  server start and rabbitmqctl stop for stopping the server
  [bsc#1180096]
* Fri Oct 30 2020 pgajdos@suse.com
- fix tests for SLE15
* Thu Sep  3 2020 pgajdos@suse.com
- do not skip test_basic, try to run rabbitmq-server instead
- deleted patches
  - rabbitmq-c-remove_failing_test-0.9.0.patch (not needed)
* Wed Sep  2 2020 pgajdos@suse.com
- rework the package [jsc#SLE-12262]:
  * run spec-cleaner
  * use cmake macros
  * source package name after github project, library package
    as subpackage
  * update to 0.10.0
  - amqp_ssl_socket_get_context can be used to get the current OpenSSL CTX*
    associated with a connection.
  - openssl: missing OpenSSL config is ignored as an OpenSSL init error (#523)
  - AMQP_DEFAULT_MAX_CHANNELS is now set to 2047 to follow current default channel
    limit in the RabbitMQ broker. (#513)
  - add additional input validation to prevent integer overflow when parsing a
    frame header. This addresses CVE-2019-18609.
* Mon May 28 2018 tuukka.pasanen@ilmi.fi
- Update to version 0.9.0
  * amqp-publish: added support for specifying headers via the -H flag
  * Add support for specifying timeout for amqp_login calls via
  * amqp_set_handshake_timeout
  * Add support for specifying timeouts in RPC-style AMQP methods via
  * amqp_set_rpc_timeout
  * Add define for AMQP_DEFAULT_VHOST
  * Support for SSL SNI
  * Support for OpenSSL v1.1.0
- Changed:
  * rabbitmq-c now requires Windows Vista or better
  * rabbitmq-c enables TCP keep-alive by default on platforms that support it
  * dropped support for compiling rabbitmq-c without threading support
  * OpenSSL is no longer un-intialized automatically by default. OpenSSL can be
    explicitly initialized by calling amqp_initialize_ssl_library and
    uninitialized by calling amqp_uninitialize_ssl_library.
- Fixed:
  * Correct bugs in processing of --url flag in tools (#364).
  * Improve documentation on AMQP_SASL_METHOD_EXTERNAL (#349)
  * Improve support for compiling under mingw-w64
  * Better support for handing SIGPIPE on Linux over SSL (#401)
  * Improve publish performance on Linux by not specifying MSG_MORE on last part
    of message.
  * Fix connection logic where multiple hostnames won't be tried if
    connection to doesn't fail immediately (#430)
- Removed:
  * autotools build system has been removed
  * many duplicate amqps_* examples, they did not add a lot of value
